/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sonar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package ch.hortis.sonar.model;

import javax.persistence.*;

@Entity
@Table(name = "snapshot_sources")
public class SnapshotSource {

  @Id
  @Column(name = "id")
  @SequenceGenerator(name = "SNAPSHOT_SOURCES_SEQ", sequenceName = "SNAPSHOT_SOURCES_SEQ")
  @GeneratedValue(strategy = GenerationType.AUTO, generator = "SNAPSHOT_SOURCES_SEQ")
  private Integer id;

  @Column(name = "snapshot_id")
  private Integer snapshotId;

  @Lob
  @Column(name = "data", updatable = true, nullable = true, length = 16777215)
  private String data;

  public SnapshotSource() {
  }

  public SnapshotSource(Snapshot snapshot, String data) {
    this.snapshotId = snapshot.getId();
    this.data = data;
  }

  public Integer getId() {
    return id;
  }

  public void setId(Integer id) {
    this.id = id;
  }

  public void setSnapshot(Snapshot snapshot) {
    this.snapshotId = snapshot.getId();
  }

  public String getData() {
    return data;
  }

  public void setData(String data) {
    this.data = data;
  }

  @Override
  public boolean equals(Object obj) {
    if (!(obj instanceof SnapshotSource)) {
      return false;
    }
    if (this == obj) {
      return true;
    }
    SnapshotSource other = (SnapshotSource) obj;
    return snapshotId.equals(other.snapshotId);
  }

  @Override
  public int hashCode() {
    return snapshotId.hashCode();
  }
}
