/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sonar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package org.sonar.commons.configuration;

import org.apache.commons.configuration.BaseConfiguration;
import org.apache.commons.configuration.event.ConfigurationListener;
import org.sonar.commons.database.DatabaseManager;
import org.sonar.commons.database.DatabaseManagerFactory;

import java.util.List;

public class DatabaseConfiguration extends BaseConfiguration {
  protected DatabaseConfiguration(DatabaseManagerFactory dmf, ConfigurationListener listener) {
    load(dmf);
    addConfigurationListener(listener);
  }

  public DatabaseConfiguration(DatabaseManagerFactory dmf) {
    this(dmf, new DatabaseConfigurationListener(dmf));
  }

  protected void load(DatabaseManagerFactory dmf) {
    DatabaseManager database = dmf.getDatabaseManager();
    database.start();
    try {
      List<Property> properties = database.createQuery("select p from Property p").getResultList();
      if (properties != null) {
        for (Property property : properties) {
          setProperty(property.getKey(), property.getValue());
        }
      }
    } finally {
      database.stop();
    }
  }
}
