/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sonar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package org.sonar.commons.measures;

import org.sonar.commons.measures.Measure;
import ch.hortis.sonar.model.Snapshot;
import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;
import org.apache.commons.lang.builder.ToStringBuilder;

import javax.persistence.*;
import java.sql.Blob;

@Entity
@Table(name = "measure_parameters")
public class MeasureParameter {

  public static final int PARAM_KEY_COLUMN_SIZE = 100;

  @Id
  @Column(name = "id")
  @SequenceGenerator(name = "MEASURE_PARAMETERS_SEQ", sequenceName = "MEASURE_PARAMETERS_SEQ")
  @GeneratedValue(strategy = GenerationType.AUTO, generator = "MEASURE_PARAMETERS_SEQ")
  private Integer id;

  @Column(name = "param_key", updatable = false, nullable = true, length = PARAM_KEY_COLUMN_SIZE)
  private String key;

  @Column(name = "value", updatable = false, nullable = true, precision = 30, scale = 20)
  private Double value = 0.0;

  @Column(name = "lob_value", updatable = false, nullable = true)
  private Blob lobValue;

  @Column(name = "text_value", updatable = true, nullable = true, length = 2048)
  private String textValue;

  @ManyToOne(fetch = FetchType.LAZY)
  @JoinColumn(name = "measure_id")
  private Measure measure;

  @Column(name = "snapshot_id")
  private Integer snapshotId;


  public MeasureParameter(String key, Blob lobValue, Double value) {
    setKey(key);
    this.value = value;
    this.lobValue = lobValue;
  }

  public MeasureParameter() {
  }

  public Integer getId() {
    return id;
  }

  public void setId(Integer id) {
    this.id = id;
  }

  public String getKey() {
    return key;
  }

  public void setKey(String key) {
    if (key.length() > PARAM_KEY_COLUMN_SIZE) {
      throw new IllegalArgumentException("MeasureParameter key " + key + " size too long :" + key.length());
    }
    this.key = key;
  }

  public Double getValue() {
    return value;
  }

  public void setValue(Double value) {
    this.value = value;
  }

  public Blob getLobValue() {
    return lobValue;
  }

  public void setLobValue(Blob lobValue) {
    this.lobValue = lobValue;
  }

  public Measure getMeasure() {
    return measure;
  }

  public void setMeasure(Measure measure) {
    this.measure = measure;
  }

  public void setSnapshot(Snapshot snapshot) {
    this.snapshotId = snapshot.getId();
  }

  public String getTextValue() {
    return textValue;
  }

  public void setTextValue(String textValue) {
    this.textValue = textValue;
  }

  @Override
  public boolean equals(Object obj) {
    if (!(obj instanceof MeasureParameter)) {
      return false;
    }
    if (this == obj) {
      return true;
    }
    MeasureParameter other = (MeasureParameter) obj;
    return new EqualsBuilder()
      .append(measure, other.getMeasure())
      .append(key, other.getKey()).isEquals();
  }

  @Override
  public int hashCode() {
    return new HashCodeBuilder(17, 37).
      append(id).toHashCode();
  }

  @Override
  public String toString() {
    return new ToStringBuilder(this).
      append("key", key).
      append("value", value).
      append("lobValue", lobValue).
      append("measure", measure).
      append("snapshot id", snapshotId).
      toString();
  }


}